import React, { useState, useEffect } from "react";
import {
  Box,
  Typography,
  Grid,
  Button,
  Table,
  TableBody,
  TableCell,
  TableHead,
  TableRow,
  Paper,
  Divider,
} from "@mui/material";
import { useNavigate, useParams } from "react-router-dom";
import { TableContainer } from "@material-ui/core";
import axios from "axios"; // Import axios for HTTP requests
import { isAutheticated } from "src/auth";
import InvoiceTable from "../orders/invoiceTable";
import PendingOrderTable from "../orders/pendingOrderTable";

const RDViewOrder = () => {
  const [order, setOrder] = useState(null); // State to store order details
  const token = isAutheticated(); // State for delivery date
  const [loading, setLoading] = useState(true); // Loading state
  const [error, setError] = useState(null); // Error state
  const navigate = useNavigate();
  const { id } = useParams();
  // Get order ID from URL params

  useEffect(() => {
    const fetchOrderDetails = async () => {
      try {
        const response = await axios.get(
          `/api/get-single-placed-order-rd/${id}`,
          {
            headers: {
              Authorization: `Bearer ${token}`,
            },
          }
        );
        // console.log(response);
        setOrder(response.data.singleOrder);
        setLoading(false);
      } catch (err) {
        setError("Failed to fetch order details");
        setLoading(false);
      }
    };

    fetchOrderDetails();
  }, [id]);

  if (loading) {
    return <Typography>Loading...</Typography>;
  }

  if (error) {
    return <Typography color="error">{error}</Typography>;
  }

  return (
    <Box>
      <Box
        display="flex"
        justifyContent="space-between"
        alignItems="center"
        mb={5}
      >
        <Typography variant="h4" sx={{ flexGrow: 1, textAlign: "center" }}>
          Order ID: {order?.uniqueId}
        </Typography>
        <Button
          color="primary"
          onClick={() => navigate(`/retailer/order`)}
          variant="contained"
        >
          Back
        </Button>
      </Box>
      <Grid container spacing={2}>
        <Grid item md={8} xl={8} lg={8}>
          <Box sx={{ padding: 2, background: "#fff" }}>
            {order.invoices?.length > 0 && (
              <>
                <Typography variant="h4" gutterBottom>
                  Invoices
                </Typography>
                <InvoiceTable invoices={order.invoices} />
              </>
            )}
            <Typography variant="h4" my={3} gutterBottom>
              Order Summary
            </Typography>

            <Grid container spacing={2}>
              <Grid item xs={12}>
                <TableContainer component={Paper}>
                  <Table>
                    <TableHead>
                      <TableRow>
                        <TableCell>Product</TableCell>
                        <TableCell align="right">Price (₹)</TableCell>
                        <TableCell align="right">Order Quantity</TableCell>
                        <TableCell align="right">Subtotal (₹)</TableCell>
                        <TableCell align="right">GST (%)</TableCell>
                        <TableCell align="right">GST Amount (₹)</TableCell>
                        <TableCell align="right">Total with GST (₹)</TableCell>
                      </TableRow>
                    </TableHead>
                    <TableBody>
                      {order?.orderItem.map((item, index) => {
                        const subtotal = item.price * item.quantity;
                        const gstAmount = (
                          ((item.GST * item.price) / 100) *
                          item.quantity
                        ).toFixed(2);
                        const totalWithGST = (
                          subtotal + parseFloat(gstAmount)
                        ).toFixed(2);

                        return (
                          <TableRow key={index}>
                            <TableCell>
                              {item.image.length > 0 && (
                                <img
                                  src={item?.image[0]?.url}
                                  alt={item.name}
                                  style={{
                                    width: 50,
                                    height: 50,
                                    marginRight: 10,
                                  }}
                                />
                              )}
                              <Typography variant="subtitle1">
                                {item.name}
                              </Typography>
                            </TableCell>
                            <TableCell align="right">₹{item.price}</TableCell>
                            <TableCell align="center">
                              {item.quantity}
                            </TableCell>
                            <TableCell align="right">₹{subtotal}</TableCell>
                            <TableCell align="right">{item.GST}%</TableCell>
                            <TableCell align="right">₹{gstAmount}</TableCell>
                            <TableCell align="right">₹{totalWithGST}</TableCell>
                          </TableRow>
                        );
                      })}
                    </TableBody>
                  </Table>
                </TableContainer>
              </Grid>
            </Grid>
            {order.invoices?.length > 0 && (
              <>
                {" "}
                <Typography variant="h4" my={3} gutterBottom>
                  Order Items{" "}
                  {order?.status == "pending" ? "to be Processed" : "Cancelled"}
                </Typography>
                <PendingOrderTable order={order} />
              </>
            )}

            <Grid container spacing={2}>
              <Grid item sm={6} md={6} xl={6}>
                <Box
                  sx={{
                    marginTop: 4,
                    padding: 2,
                    backgroundColor: "blue",
                    color: "white",
                  }}
                >
                  <Typography variant="h5" gutterBottom>
                    Order Summary
                  </Typography>
                  <Divider sx={{ marginBottom: 2 }} />
                  <Typography>
                    Total Items: {order?.orderItem.length}
                  </Typography>

                  <Typography>Total Subtotal: ₹{order?.subtotal}</Typography>
                  <Typography>Total GST: ₹{order?.gstTotal}</Typography>
                  <Typography variant="h5" sx={{ marginTop: 2 }}>
                    Grand Total: ₹{order?.grandTotal}
                  </Typography>
                </Box>
              </Grid>
            </Grid>
          </Box>
        </Grid>
        <Grid item md={4} xl={4} lg={4}>
          <Box
            sx={{
              background: "#fff",
              padding: "1rem",
              borderRadius: "0.8rem",
            }}
          >
            <Grid container spacing={2}>
              <Grid item sm={12} md={12} lg={12}>
                <Typography variant="h5" sx={{ mb: "0.5rem" }}>
                  Retailer Details
                </Typography>
                <Typography sx={{ mb: "0.5rem" }}>
                  <strong>SBU:</strong> {order?.addedBy.uniqueId}
                </Typography>
                <Typography sx={{ mb: "0.5rem" }}>
                  <strong>Name:</strong> {order?.addedBy.name}
                </Typography>
                <Typography sx={{ mb: "0.5rem" }}>
                  <strong>Email id:</strong> {order?.addedBy.email}
                </Typography>
                <Typography sx={{ mb: "0.5rem" }}>
                  <strong>Number:</strong> {order?.addedBy.mobile_number}
                </Typography>
              </Grid>
              <Grid item sm={12} md={12} lg={12}>
                <Typography variant="h5" sx={{ mb: "0.5rem" }}>
                  Respected PD Details
                </Typography>
                <Typography sx={{ mb: "0.5rem" }}>
                  <strong>SBU:</strong> {order?.pd.SBU}
                </Typography>
                <Typography sx={{ mb: "0.5rem" }}>
                  <strong>Name:</strong> {order?.pd.name}
                </Typography>
                <Typography sx={{ mb: "0.5rem" }}>
                  <strong>Email id:</strong> {order?.pd.email}
                </Typography>
                <Typography sx={{ mb: "0.5rem" }}>
                  <strong>Number:</strong> {order?.pd.phone}
                </Typography>
              </Grid>
              <Grid item sm={6} md={6} lg={6}>
                <Typography variant="h5" sx={{ mb: "0.5rem" }}>
                  Bill Address
                </Typography>
                <Typography sx={{ mb: "0.5rem" }}>{order?.billTo}</Typography>
              </Grid>
              <Grid item sm={6} md={6} lg={6}>
                <Typography variant="h5" sx={{ mb: "0.5rem" }}>
                  Ship Address
                </Typography>
                <Typography sx={{ mb: "0.5rem" }}>{order?.shipTo}</Typography>
              </Grid>
              <Grid item sm={6} md={6} lg={6}>
                <Typography variant="h5" sx={{ mb: "0.5rem" }}>
                  Payment mode
                </Typography>
                <Typography sx={{ mb: "0.5rem" }}>
                  {order?.paymentMode}
                </Typography>
              </Grid>

              <Grid item sm={12} md={12} lg={12}>
                <Typography variant="h5" sx={{ mb: "0.5rem" }}>
                  Order Status
                </Typography>
                <Typography sx={{ mb: "0.5rem" }}>{order?.status}</Typography>
                {order?.status === "cancelled" && (
                  <Typography sx={{ mb: "0.5rem", color: "red" }}>
                    {order?.order_Cancelled_Reason}
                  </Typography>
                )}
              </Grid>
            </Grid>
          </Box>
        </Grid>
      </Grid>
    </Box>
  );
};
// const formatAMPM = (date) => {
//   var hours = new Date(date).getHours();
//   var minutes = new Date(date).getMinutes();
//   var ampm = hours >= 12 ? "PM" : "AM";
//   hours = hours % 12;
//   hours = hours ? hours : 12;
//   minutes = minutes < 10 ? "0" + minutes : minutes;
//   var strTime = hours + ":" + minutes + " " + ampm;
//   return strTime;
// };
export default RDViewOrder;
